#!/usr/bin/env python3
 
import sys
import tkinter

 
def draw_grid(width, height, n):
    """
    Given a width, height, and number of cells per row/column, this function
    draws a grid where all cells have the same size and each row is
    labelled with its corresponding y-coordinate.

    Input:
        width (int) - width of the canvas
        height (int) - height of the canvas
        n (int) - number of cells per row/column of the grid
    """
    canvas = make_canvas(width, height)

    # your code here


def make_canvas(width, height):
    """
    (provided, DO NOT EDIT)
    This function takes in a specified width and height and creates
    a Tkinter canvas with that width and height. It also outlines
    the edge of the canvas in blue to demarcate the canvas in the GUI
    window.

    Input:
        width (int) - canvas width
        height (int) - canvas height

    Returns
        canvas (Tkinter Canvas) - blank canvas with specified width and height
    """
    top = tkinter.Tk()
    top.minsize(width=width + 10, height=height + 10)

    canvas = tkinter.Canvas(top, width=width, height=height)
    canvas.pack()
    canvas.xview_scroll(6, 'units')  # hack so (0, 0) works correctly
    canvas.yview_scroll(6, 'units')

    # draw blue boundaries - sides
    canvas.create_line(0, 0, 0, height - 1, fill='blue')
    canvas.create_line(width - 1, 0, width - 1, height - 1, fill='blue')
    # top to bottom
    canvas.create_line(0, 0, width - 1, 0, fill='blue')
    canvas.create_line(0, height - 1, width - 1, height - 1, fill='blue')
    return canvas

# Default canvas size
WIDTH = 500
HEIGHT = 300


def main():
    args = sys.argv[1:]
 
    # args:
    # n               # draws 500x300 with this n
    if len(args) == 1:
        draw_grid(WIDTH, HEIGHT, int(args[0]))
        # required line puts the canvas-window up on screen
        tkinter.mainloop()
 
    # args:
    # width height n  # draws custom size grid with n
    if len(args) == 3:
        draw_grid(int(args[0]), int(args[1]), int(args[2]))
        # required  line puts the canvas-window up on screen
        tkinter.mainloop()
 
 
if __name__ == '__main__':
    main()
